%define upstream_name    Test-Refcount
%define upstream_version 0.10

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Assert reference counts on objects
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Test/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(B)
BuildRequires: perl(Module::Build) >= 0.400.400
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Test::Builder)
BuildRequires: perl(Test::Builder::Tester)
BuildRequires: perl(Test::More) >= 0.880.0
BuildArch:  noarch

%description
The Perl garbage collector uses simple reference counting during the normal
execution of a program. This means that cycles or unweakened references in
other parts of code can keep an object around for longer than intended. To
help avoid this problem, the reference count of a new object from its class
constructor ought to be 1. This way, the caller can know the object will be
properly DESTROYed when it drops all of its references to it.

This module provides two test functions to help ensure this property holds
for an object class, so as to be polite to its callers.

If the assertion fails; that is, if the actual reference count is different
to what was expected, a trace of references to the object is printed, using
Marc Lehmann's the Devel::FindRef manpage module. See the examples below
for more information.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=$RPM_BUILD_ROOT --create_packlist=0

%check
./Build test

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Mon Mar 21 2022 umeabot <umeabot> 0.100.0-3.mga9
+ Revision: 1811766
- Mageia 9 Mass Rebuild

* Sat Feb 15 2020 umeabot <umeabot> 0.100.0-2.mga8
+ Revision: 1527298
- Mageia 8 Mass Rebuild

* Mon Jul 15 2019 tv <tv> 0.100.0-1.mga8
+ Revision: 1421442
- update to 0.10

* Wed Sep 19 2018 umeabot <umeabot> 0.80.0-6.mga7
+ Revision: 1271993
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.80.0-5.mga6
+ Revision: 1034584
- Rebuild for perl 5.22.2

* Mon Feb 01 2016 umeabot <umeabot> 0.80.0-4.mga6
+ Revision: 930285
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.80.0-3.mga5
+ Revision: 740330
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.80.0-2.mga5
+ Revision: 686524
- Mageia 5 Mass Rebuild

* Tue Apr 22 2014 jquelin <jquelin> 0.80.0-1.mga5
+ Revision: 617380
- update to 0.08

* Fri Oct 18 2013 umeabot <umeabot> 0.70.0-3.mga4
+ Revision: 515354
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.70.0-2.mga3
+ Revision: 373731
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jun 15 2011 jquelin <jquelin> 0.70.0-1.mga2
+ Revision: 107472
- update to 0.07

* Mon Jan 24 2011 jquelin <jquelin> 0.60.0-2.mga1
+ Revision: 36886
- rebuild

* Sun Jan 23 2011 jquelin <jquelin> 0.60.0-1.mga1
+ Revision: 34952
- mageia rebuild
- imported package perl-Test-Refcount


* Fri Nov 27 2009 Jérôme Quelin <jquelin@mandriva.org> 0.60.0-1mdv2011.0
+ Revision: 470460
- update to 0.06

* Fri Nov 27 2009 Götz Waschk <waschk@mandriva.org> 0.60.0-1mdv2010.1
+ Revision: 470452
- update to new version 0.06

* Fri Jul 10 2009 Jérôme Quelin <jquelin@mandriva.org> 0.50.0-1mdv2010.0
+ Revision: 394270
- update to 0.05

* Mon Jun 29 2009 Götz Waschk <waschk@mandriva.org> 0.40.0-1mdv2010.0
+ Revision: 390501
- import perl-Test-Refcount


* Mon Jun 29 2009 cpan2dist 0.04-1mdv
- initial mdv release, generated with cpan2dist

